@@ -112,18 +112,19 @@ def max_sim(model, document_vec, concept_vec):
     comparisons = 0
     start_time = time.time()
     for term_1 in document_vec:
-        max_similarity = 0
+        max_similarity = -1
         matched_term = None
         for term_2 in concept_vec:
             comparisons += 1
             current_similarity = model.similarity(term_1, term_2)
-            if current_similarity <0:
+            if current_similarity< -1:
+                print(current_similarity)
                 current_similarity=0
             if current_similarity > max_similarity:
                 max_similarity = current_similarity
                 matched_term = term_2
             elif max_similarity >= 1.0:
-                break
+                print(max_similarity)
             else:
                 continue
         if matched_term != None:
@@ -171,7 +172,7 @@ def initialize_model(path_corpus,path_model,path_model_vocab,n):
         esa_matrix = get_esa_matrix(top_n, tfidf, concepts)
         normalize(esa_matrix)
         model = gensim.models.keyedvectors.KeyedVectors.load_word2vec_format(path_model, binary = True)
-
+        model.init_sims(replace=True)
 def model_topic(path_corpus,path_model,path_model_vocab,text,n):
     if n == -1:
         n = None
